@@ -789,9 +789,9 @@ class CHGraph(object):
                     src_target_field_list_con = src_info["id"] + "," + ",".join(src_info["fields"])
                     if "_time" not in src_info["fields"]:
                         src_target_field_list_con = src_target_field_list_con + ",_time"
-                    self.client.execute(
-                        "insert into " + src_db_table_new + " (" + src_target_field_list_con + ") select distinct " + src_target_field_list_con + " from " + src_db_table_old + " where " +
-                        src_info["id"] + " in " + tostr(col_list[0]))
+                    insert_src_sql = "insert into " + src_db_table_new + " (" + src_target_field_list_con + ") select distinct " + src_target_field_list_con + " from " + src_db_table_old + " where " +\
+                                     src_info["id"] + " in " + tostr(col_list[0])
+                    self.client.execute(insert_src_sql)
                     dst_info = self.graph_cfg["vertexes"][edge_info["dst_type"]]
                     dst_db_table_new = subgraph_name + "." + dst_info["table"]
                     dst_db_table_old = main_db + "." + dst_info["table"]
@@ -799,9 +799,9 @@ class CHGraph(object):
                     if "_time" not in dst_info["fields"]:
                         dst_target_field_list_con = dst_target_field_list_con + ",_time"
 
-                    self.client.execute(
-                        "insert into " + dst_db_table_new + " (" + dst_target_field_list_con + ") select distinct " + dst_target_field_list_con + " from " + dst_db_table_old + " where " +
-                        dst_info["id"] + " in " + tostr(col_list[1]))
+                    insert_dst_sql = "insert into " + dst_db_table_new + " (" + dst_target_field_list_con + ") select distinct " + dst_target_field_list_con + " from " + dst_db_table_old + " where " +\
+                                     dst_info["id"] + " in " + tostr(col_list[1])
+                    self.client.execute(insert_dst_sql)
             return multi_res
         except Exception as e:
             print(e)
